@@ -6,8 +6,8 @@ Created on Sun Jul 21 22:15:30 2019
 """
 
 from numpy import asarray, array
-from flexsolve import aitken_secant, IQ_interpolation, safe_divide
-from .solve_composition import solve_x
+from flexsolve import aitken_secant, IQ_interpolation
+from .solve_vle_composition import solve_x
 from ..utils import fill_like
 from .._settings import settings
 
@@ -88,7 +88,7 @@ class DewPoint:
     def _T_error(self, T, P, z_norm, zP):
         Psats = array([i(T) for i in self.Psats])
         phi = self.phi(z_norm, T, P)
-        x_gamma_pcf = safe_divide(phi * zP, Psats)
+        x_gamma_pcf = phi * zP / Psats
         self.x = solve_x(x_gamma_pcf, self.gamma, self.pcf, T, self.x)
         return 1 - self.x.sum()
     
@@ -155,7 +155,7 @@ class DewPoint:
                                       x=T, args=args, xtol=1e-4, ytol=1e-4)
                 
         self.x /= self.x.sum()
-        return self.T, self.x
+        return self.T, self.x.copy()
     
     def solve_Px(self, z, T):
         """
@@ -202,7 +202,7 @@ class DewPoint:
             self.P = self.rootsolver(self._P_error, P, P+1, 
                                      1e-2, 5e-8, args)
         self.x /= self.x.sum()
-        return self.P, self.x
+        return self.P, self.x.copy()
     
     def __repr__(self):
         chemicals = ", ".join([i.ID for i in self.chemicals])
