@@ -13,15 +13,15 @@ __all__ = ('UndefinedChemical',
 
 class UndefinedChemical(AttributeError):
     """AttributeError regarding undefined chemicals."""
-    def __init__(self, ID): super().__init__(f"'{ID}'")
+    def __init__(self, ID): super().__init__(repr(ID))
     
 class UndefinedPhase(AttributeError):
     """AttributeError regarding undefined phases."""
-    def __init__(self, phase): super().__init__(f"'{phase}'")
+    def __init__(self, phase): super().__init__(repr(phase))
 
 class UndefinedPhaseOrChemical(AttributeError):
     """AttributeError regarding undefined phases or chemicals."""
-    def __init__(self, phase_or_ID): super().__init__(f"'{phase_or_ID}'")
+    def __init__(self, phase_or_ID): super().__init__(repr(phase_or_ID))
 
 class DimensionError(ValueError):
     """ValueError regarding wrong dimensions."""
